@@ -1,5 +1,5 @@
 from easydev.console import *
-
+from easydev import console
 
 def test_get_terminal_width():
     get_terminal_width()
@@ -14,5 +14,7 @@ def test_coloron():
     nocolor()
     coloron()
 
+
 def test_print_color():
     print purple('\t%s' % "test")
+    print red('\t%s' % "test")
